<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>defaultlook</name>
    <message>
        <location filename="defaultlook.ui" line="20"/>
        <location filename="defaultlook.cpp" line="58"/>
        <location filename="defaultlook.cpp" line="502"/>
        <location filename="defaultlook.cpp" line="509"/>
        <location filename="defaultlook.cpp" line="526"/>
        <location filename="defaultlook.cpp" line="537"/>
        <location filename="defaultlook.cpp" line="547"/>
        <source>MX Tweak</source>
        <translation>MX Ulepszenia</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Ustawienia Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dostosuj panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="77"/>
        <location filename="defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Skonfiguruj zachowanie okna i skróty&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Menedżer okien</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dostosuj wygląd swojego pulpitu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Utwórz kopię zapasową konfiguracji panelu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Przywróć kopię zapasową konfiguracji panelu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Przywróć domyślny panel</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Dotyczy 1-go panelu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Wyświetl panel pionowo</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Na dole</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Na górze</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Wyświetl panel poziomo</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Na lewo</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Na prawo</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dotyczy wszystkich paneli&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Przyciski okien&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="446"/>
        <location filename="defaultlook.ui" line="549"/>
        <location filename="defaultlook.ui" line="740"/>
        <location filename="defaultlook.ui" line="894"/>
        <location filename="defaultlook.ui" line="936"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Motyw</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Opcje motywu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Napraw niektóre pola witryny przy użyciu ciemnego motywu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Modyfikacja ciemnego motywu Firefoksa</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Napraw pole wprowadzania w programie HexChat w ciemnym motywie</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <translation>Usuń zestaw motywów użytkownika</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Zapisz bieżące ustawienia jako zestaw motywów</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="614"/>
        <location filename="defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>Kompozytor</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Uruchom narzędzie konfiguracyjne compton-conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Ustawienia Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ustawienia kompozytora Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Ustawienia Xfwm</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>Żaden</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Kompozytor Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Edytuj plik compton.conf bezpośrednio w edytorze tekstu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Edytuj compton.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Opcje przezroczystości i cienia</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="800"/>
        <source>off</source>
        <translation>wyłącz</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="811"/>
        <source>Config Options</source>
        <translation>Opcje konfiguracji</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="819"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Zresetuj Lightdm (ekran logowania) do domyślnego motywu systemowego</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="826"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Zresetuj spersonalizowane działania prawego przycisku myszy dla Thunara do domyślnych ustawień systemowych</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="833"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Użyj sterownika intel zamiast domyślnego sterownika &quot;modesetting&quot; (wymaga ponownego uruchomienia)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="840"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>UWAGA: istniejący plik /etc/X11/xorg.conf.d/20-intel.conf zostanie skopiowany do folderu domowego</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="847"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Użyj opcji tearfree amdgpu </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="854"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          UWAGA: istniejący plik /etc/X11/xorg.conf.d/20-amd.conf zostanie skopiowany do folderu domowego</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="861"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Użyj opcji sterownika tearfree radeon</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="868"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          UWAGA: istniejący plik /etc/X11/xorg.conf.d/20-radeon.conf zostanie skopiowany do folderu domowego</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="908"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="916"/>
        <source>Enable single-click on desktop</source>
        <translation>Włącz uruchamianie jednym kliknięciem na pulpicie</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="923"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Włącz uruchamianie jednym kliknięciem w menedżerze plików Thunar</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="960"/>
        <source>Show systray (notification area) frame</source>
        <translation>Pokaż ramkę zasobnika systemowego (obszar powiadomień)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="967"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Pokaż w panelu okna ze wszystkich obszarów roboczych</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="974"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Pozwól na montowanie dysków wewnętrznych przez użytkowników innych niż root</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="981"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Wyłącz skracanie długich nazw plików na pulpicie</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="988"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Włącz opcję hibernacji w menu Wyloguj</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="995"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>uwaga: wybierając hibernację, swap musi być &gt;= RAM</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="501"/>
        <source>About MX Tweak</source>
        <translation>O programie MX Ulepszenia</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="502"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="503"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplikacja do szybkiego zmieniania wyglądu i dostosowywania interfejsu do potrzeb użytkownika</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="505"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="506"/>
        <location filename="defaultlook.cpp" line="509"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="507"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="538"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Gotowe! Firefox może wymagać ponownego uruchomienia, aby zmiany przyniosły efekt</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="548"/>
        <source>This app is Xfce-only</source>
        <translation>Ta aplikacja jest dostępna tylko w Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="690"/>
        <source>Panel settings</source>
        <translation>Ustawienia panelu</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="691"/>
        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Twoje bieżące ustawienia panelu zostały zapisane w ukrytym folderze o nazwie .restore w twoim katalogu domowym (~/.restore/)</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="1117"/>
        <source>Choose a theme set</source>
        <translation>Wybierz zestaw motywów</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Usuń zestaw motywów użytkownika</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nowy zestaw motywów</translation>
    </message>
    <message>
        <location filename="theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Wpisz nazwę nowego zestawu motywów</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="window_buttons.ui" line="14"/>
        <location filename="window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Przyciski okien</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wygląd&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Pokaż etykiety przycisków</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Pokaż płaskie przyciski</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Pokaż uchwyt</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Kolejność sortowania:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Według znacznika czasu</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Według nazwy grupy i znacznika czasu</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Według nazwy okna</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Według nazwy grupy i okna</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Brak, pozwalaj na przeciągnij i upuść</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Zachowanie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Grupowanie okien:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Zawsze</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Kliknięcie środkowym przyciskiem:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Zamknij okno</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Zminimalizuj okno</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Przywróć zminimalizowane okna do bieżącego obszaru roboczego</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Rysuj ramkę okna po najechaniu kursorem na przycisk</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Przełączanie okien kółkiem myszy</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrowanie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Pokaż okna ze wszystkich obszarów roboczych lub obszarów wyświetlania</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Pokaż tylko zminimalizowane okna</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Pokaż okna ze wszystkich monitorów</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Wyskakujące okna</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Okna podczas przenoszenia</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ustawienia nieprzezroczystości&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Dekoracje okien</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Pokaż cienie pod zadokowanymi oknami</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Pokaż cienie pod wyskakującymi oknami</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Okna podczas zmiany rozmiaru</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Pokaż cienie pod standardowymi oknami</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ustawienia funkcji&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Pokaż podgląd okien zamiast ikon podczas przełączania okien</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Wyświetlaj bezpośrednio pełnoekranowe nakładki okien</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Nieaktywne okna</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Zsynchronizuj rysowanie do pionowego pustego miejsca</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Ustawienia kompozytora Xfwm</translation>
    </message>
</context>
</TS>